| get_metrics_internal | R Documentation |
Calculates a risk model's deviance, accuracy, sensitivity, specificity, AUC, and AUPRC given a set of data and a threshold value.
get_metrics_internal(
mod,
X = NULL,
y = NULL,
weights = NULL,
threshold = 0.5,
threshold_type = c("response", "score")
)
mod |
An object of class |
X |
Input covariate matrix with dimension |
y |
Numeric vector for the (binomial) response variable. |
weights |
Numeric vector of length |
threshold |
Numeric vector of classification threshold values used to calculate the accuracy, sensitivity, and specificity of the model. Defaults to a range of risk probability thresholds from 0.1 to 0.9 by 0.1. |
threshold_type |
Defines whether the |
List with deviance (dev), accuracy (acc), sensitivity (sens), specificity (spec), auc, and auprc.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.